@@ -9,8 +9,8 @@
 #' 
 #' @param x An object of class \code{netsplit}.
 #' @param pooled A character string indicating whether results for the
-#'   fixed effect (\code{"fixed"}) or random effects model
-#'   (\code{"random"}) should be plotted. Can be abbreviated.
+#'   common (\code{"common"}) or random effects model (\code{"random"})
+#'   should be plotted. Can be abbreviated.
 #' @param show A character string indicating which comparisons should
 #'   be printed (see Details).
 #' @param overall A logical indicating whether network meta-analysis
@@ -76,8 +76,7 @@
 #'   than log odds ratios, for example.
 #' @param lab.NA A character string to label missing values.
 #' @param smlab A label printed at top of figure. By default, text
-#'   indicating either fixed effect or random effects model is
-#'   printed.
+#'   indicating either common or random effects model is printed.
 #' @param \dots Additional arguments for \code{\link{forest.meta}}
 #'   function.
 #' 
@@ -131,8 +130,7 @@
 #' Senn2013.5 <- subset(Senn2013, studlab %in% studies[1:5])
 #' 
 #' net1 <- netmeta(TE, seTE, treat1.long, treat2.long,
-#'                 studlab, data = Senn2013.5,
-#'                 fixed = FALSE)
+#'   studlab, data = Senn2013.5, common = FALSE)
 #' #
 #' ns1 <- netsplit(net1)
 #' 
@@ -145,15 +143,14 @@
 #' # Forest plot showing comparisons contributing direct evidence
 #' #
 #' forest(ns1, fontsize = 6, spacing = 0.5, addrow.subgroups = FALSE,
-#'        show = "with.direct")
+#'   show = "with.direct")
 #'
 #' 
 #' # Forest plot only showing network estimates compared to reference
 #' # group and prediction intervals
 #' #
 #' forest(ns1, fontsize = 8, spacing = 0.75,
-#'        show = "ref", prediction = TRUE,
-#'        direct = FALSE, indirect = FALSE)
+#'   show = "ref", prediction = TRUE, direct = FALSE, indirect = FALSE)
 #' }
 #' 
 #' @method forest netsplit
@@ -161,7 +158,7 @@
 
 
 forest.netsplit <- function(x,
-                            pooled = ifelse(x$x$random, "random", "fixed"),
+                            pooled = ifelse(x$x$random, "random", "common"),
                             show = "both",
                             ##
                             subgroup = "comparison",
@@ -216,7 +213,8 @@ forest.netsplit <- function(x,
   chkclass(x, "netsplit")
   x <- updateversion(x)
   ##
-  pooled <- setchar(pooled, c("fixed", "random"))
+  pooled <- setchar(pooled, c("common", "random", "fixed"))
+  pooled[pooled == "fixed"] <- "common"
   ##
   subgroup <- setchar(subgroup, c("comparison", "estimate"))
   ##
@@ -231,11 +229,10 @@ forest.netsplit <- function(x,
   ##
   ## Catch sortvar from data:
   ##
-  mf <- match.call()
-  error <- try(sortvar.x <- eval(mf[[match("sortvar", names(mf))]],
-                                 x,
-                                 enclos = sys.frame(sys.parent())),
-               silent = TRUE)
+  error <-
+    try(sortvar.x <-
+          catch("sortvar", match.call(), x, sys.frame(sys.parent())),
+        silent = TRUE)
   if (!any(class(error) == "try-error"))
     sortvar <- sortvar.x
   ##
@@ -300,10 +297,10 @@ forest.netsplit <- function(x,
   ##
   chkchar(lab.NA)
   ##
-  if (pooled == "fixed") {
+  if (pooled == "common") {
     if (!(missing(prediction)) & prediction)
       warning("Prediction intervals not shown for estimates ",
-              "from fixed effect model.")
+              "from common effects model.")
     prediction <- FALSE
   }
   ##
@@ -326,6 +323,7 @@ forest.netsplit <- function(x,
     leftlabs <- rep(NA, length(leftcols))
     leftlabs[leftcols == "studlab"] <- "Comparison"
     leftlabs[leftcols == "k"] <- "Number of\nStudies"
+    leftlabs[leftcols == "n"] <- "Number of\nParticipants"
     leftlabs[leftcols == "prop"] <- "Direct\nEvidence"
     leftlabs[leftcols == "I2"] <- "I2"
     leftlabs[leftcols == "tau2"] <- "tau2"
@@ -411,26 +409,26 @@ forest.netsplit <- function(x,
   
   ##
   ##
-  ## (2) Extract results for fixed effect and random effects model
+  ## (2) Extract results for common and random effects model
   ##
   ##
-  if (pooled == "fixed") {
-    dat.direct <- x$direct.fixed
+  if (pooled == "common") {
+    dat.direct <- x$direct.common
     ##
-    dat.indirect <- x$indirect.fixed
+    dat.indirect <- x$indirect.common
     dat.indirect$Q <- dat.indirect$tau2 <-
       dat.indirect$tau <- dat.indirect$I2 <- NA
     ##
-    dat.overall <- x$fixed
+    dat.overall <- x$common
     dat.overall$Q <- dat.overall$tau2 <-
       dat.overall$tau <- dat.overall$I2 <- NA
     ##
-    dat.direct$prop <- formatPT(x$prop.fixed, digits = digits.prop)
+    dat.direct$prop <- formatPT(x$prop.common, digits = digits.prop)
     dat.indirect$prop <- NA
     dat.overall$prop <- NA
     ##
     if (missing.smlab)
-      smlab <- "Fixed effect model"
+      smlab <- "Common effects model"
   }
   else {
     dat.direct <- x$direct.random
@@ -486,6 +484,8 @@ forest.netsplit <- function(x,
   dat.direct$k <- x$k
   dat.indirect$k <- dat.overall$k <- dat.predict$k <- NA
   ##
+  dat.indirect$n <- dat.overall$n <- dat.predict$n <- NA
+  ##
   dat.direct$evidence   <- text.direct
   dat.indirect$evidence <- text.indirect
   dat.overall$evidence  <- text.overall
@@ -537,18 +537,18 @@ forest.netsplit <- function(x,
   ##
   ##
   if (show == "all")
-    sel <- rep_len(TRUE, length(x$direct.fixed$TE))
+    sel <- rep_len(TRUE, length(x$direct.common$TE))
   else if (show == "with.direct")
-    sel <- (!is.na(x$direct.fixed$TE) & !is.na(x$direct.random$TE))
+    sel <- (!is.na(x$direct.common$TE) & !is.na(x$direct.random$TE))
   else if (show == "both")
-    sel <- (!is.na(x$direct.fixed$TE)  & !is.na(x$indirect.fixed$TE) &
+    sel <- (!is.na(x$direct.common$TE)  & !is.na(x$indirect.common$TE) &
             !is.na(x$direct.random$TE) & !is.na(x$indirect.random$TE))
   else if (show == "direct.only")
-    sel <- (!is.na(x$direct.fixed$TE)  & is.na(x$indirect.fixed$TE) &
+    sel <- (!is.na(x$direct.common$TE)  & is.na(x$indirect.common$TE) &
             !is.na(x$direct.random$TE) & is.na(x$indirect.random$TE))
   else if (show == "indirect.only")
-    sel <- (is.na(x$direct.fixed$TE)  & !is.na(x$indirect.fixed$TE) &
-             is.na(x$direct.random$TE) & !is.na(x$indirect.random$TE))
+    sel <- (is.na(x$direct.common$TE)  & !is.na(x$indirect.common$TE) &
+            is.na(x$direct.random$TE) & !is.na(x$indirect.random$TE))
   ##
   if (only.reference) {
     if (x$reference.group == "") {
@@ -612,16 +612,16 @@ forest.netsplit <- function(x,
         suppressWarnings(metagen(dat$TE, dat$seTE,
                                  studlab = dat$evidence, data = dat,
                                  sm = x$sm,
-                                 method.tau = "DL",
+                                 method.tau = "DL", method.tau.ci = "",
                                  byvar = dat$comps, print.byvar = FALSE))
     else
       m <-
         suppressWarnings(metagen(dat$TE, dat$seTE,
                                  studlab = dat$comps, data = dat, sm = x$sm,
-                                 method.tau = "DL"))
+                                 method.tau = "DL", method.tau.ci = ""))
     ##
     if (overall) {
-      m$w.fixed[m$studlab == text.overall] <- max(m$w.fixed, na.rm = TRUE)
+      m$w.common[m$studlab == text.overall] <- max(m$w.common, na.rm = TRUE)
       m$w.random[m$studlab == text.overall] <- max(m$w.random, na.rm = TRUE)
     }
     ##
@@ -629,13 +629,13 @@ forest.netsplit <- function(x,
       m$lower[m$studlab == text.predict] <- dat.predict$lower
       m$upper[m$studlab == text.predict] <- dat.predict$upper
       ##
-      m$w.fixed[m$studlab == text.predict] <- max(m$w.fixed, na.rm = TRUE)
+      m$w.common[m$studlab == text.predict] <- max(m$w.common, na.rm = TRUE)
       m$w.random[m$studlab == text.predict] <- max(m$w.random, na.rm = TRUE)
     }
     ##
     forest(m,
            digits = digits,
-           fixed = FALSE, random = FALSE,
+           common = FALSE, random = FALSE,
            hetstat = FALSE, test.subgroup = FALSE,
            leftcols = leftcols,
            leftlabs = leftlabs,
@@ -647,7 +647,7 @@ forest.netsplit <- function(x,
            type.study = dat$type.study,
            col.square = dat$col.estimate,
            col.square.lines = dat$col.lines,
-           weight.study = if (equal.size) "same" else "fixed",
+           weight.study = if (equal.size) "same" else "common",
            ...)
   }
   else {
@@ -669,16 +669,16 @@ forest.netsplit <- function(x,
         suppressWarnings(metagen(dat$TE, dat$seTE,
                                  studlab = dat$comps, data = dat,
                                  sm = x$sm,
-                                 method.tau = "DL",
+                                 method.tau = "DL", method.tau.ci = "",
                                  byvar = dat$evidence, print.byvar = FALSE))
     else
       m <-
         suppressWarnings(metagen(dat$TE, dat$seTE,
                                  studlab = dat$comps, data = dat, sm = x$sm,
-                                 method.tau = "DL"))
+                                 method.tau = "DL", method.tau.ci = ""))
     ##
     if (overall) {
-      m$w.fixed[m$byvar == text.overall] <- max(m$w.fixed, na.rm = TRUE)
+      m$w.common[m$byvar == text.overall] <- max(m$w.common, na.rm = TRUE)
       m$w.random[m$byvar == text.overall] <- max(m$w.random, na.rm = TRUE)
     }
     ##
@@ -686,13 +686,13 @@ forest.netsplit <- function(x,
       m$lower[m$byvar == text.predict] <- dat.predict$lower
       m$upper[m$byvar == text.predict] <- dat.predict$upper
       ##
-      m$w.fixed[m$byvar == text.predict] <- max(m$w.fixed, na.rm = TRUE)
+      m$w.common[m$byvar == text.predict] <- max(m$w.common, na.rm = TRUE)
       m$w.random[m$byvar == text.predict] <- max(m$w.random, na.rm = TRUE)
     }
     ##
     forest(m,
            digits = digits,
-           fixed = FALSE, random = FALSE,
+           common = FALSE, random = FALSE,
            overall = FALSE, hetstat = FALSE, test.subgroup = FALSE,
            leftcols = leftcols,
            leftlabs = leftlabs,
@@ -704,7 +704,7 @@ forest.netsplit <- function(x,
            type.study = dat$type.study,
            col.square = dat$col.estimate,
            col.square.lines = dat$col.lines,
-           weight.study = if (equal.size) "same" else "fixed",
+           weight.study = if (equal.size) "same" else "common",
            ...)
   }
 
@@ -717,7 +717,7 @@ forest.netsplit <- function(x,
               lab.NA = lab.NA,
               backtransf = backtransf,
               smlab = smlab,
-              weight.study = if (equal.size) "same" else "fixed",
+              weight.study = if (equal.size) "same" else "common",
               ##
               args = list(
                 pooled = pooled,
@@ -748,7 +748,7 @@ forest.netsplit <- function(x,
                 digits.prop = digits.prop)
               )
 
-              
+  
   invisible(res)
 }
 
