@@ -8,8 +8,8 @@
 #' @param order A mandatory character or numerical vector specifying
 #'   the order of treatments or list of comparators (see Details).
 #' @param pooled A character string indicating whether results for the
-#'   fixed effect (\code{"fixed"}) or random effects model
-#'   (\code{"random"}) should be plotted. Can be abbreviated.
+#'   common (\code{"common"}) or random effects model (\code{"random"})
+#'   should be plotted. Can be abbreviated.
 #' @param xlab A label for the x-axis.
 #' @param level The confidence level utilised in the plot. For the
 #'   funnel plot, confidence limits are not drawn if \code{yaxis =
@@ -135,7 +135,7 @@
 #' data(Senn2013)
 #' 
 #' net1 <- netmeta(TE, seTE, treat1, treat2, studlab,
-#'                 data = Senn2013, sm = "MD")
+#'   data = Senn2013, sm = "MD")
 #' 
 #' # 'Comparison-adjusted' funnel plot not created as argument 'order'
 #' # is missing
@@ -149,7 +149,7 @@
 #' # Add result for Egger test of funnel plot asymmetry
 #' #
 #' funnel(net1, order = "pl", method.bias = "Egger",
-#'        digits.pval = 2)
+#'   digits.pval = 2)
 #' 
 #' # (Non-sensical) alphabetic order of treatments with placebo as
 #' # last treatment
@@ -162,15 +162,15 @@
 #' # plotting symbols and colours
 #' #
 #' funnel(net1, order = ord,
-#'        pch = rep(c(15:18, 1), 3), col = 1:3,
-#'        method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
+#'   pch = rep(c(15:18, 1), 3), col = 1:3,
+#'   method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
 #' 
 #' # Same results for tests of funnel plot asymmetry using reversed
 #' # order of treatments
 #' #
 #' funnel(net1, order = rev(ord),
-#'        pch = rep(c(15:18, 1), 3), col = 1:3,
-#'        method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
+#'   pch = rep(c(15:18, 1), 3), col = 1:3,
+#'   method.bias = c("Egger", "Begg", "Thompson"), digits.pval = 2)
 #' 
 #' # Calculate tests for funnel plot asymmetry
 #' #
@@ -187,7 +187,7 @@
 
 funnel.netmeta <- function(x,
                            order,
-                           pooled = ifelse(x$random, "random", "fixed"),
+                           pooled = ifelse(x$random, "random", "common"),
                            ##
                            xlab = NULL,
                            level = x$level,
@@ -240,7 +240,8 @@ funnel.netmeta <- function(x,
   chkclass(x, "netmeta")
   x <- updateversion(x)
   ##
-  pooled <- setchar(pooled, c("fixed", "random"))
+  pooled <- setchar(pooled, c("common", "random", "fixed"))
+  pooled[pooled == "fixed"] <- "common"
   chklogical(lump.comparator)
   ##
   if (missing(order))
@@ -397,9 +398,9 @@ funnel.netmeta <- function(x,
   if (is.numeric(treat2))
     treat2 <- as.character(treat2)
   ##
-  if (pooled == "fixed")
+  if (pooled == "common")
     for (i in seq_along(res$TE))
-      res$TE.direct[i] <- x$TE.direct.fixed[treat1[i], treat2[i]]
+      res$TE.direct[i] <- x$TE.direct.common[treat1[i], treat2[i]]
   else
     for (i in seq_along(res$TE))
       res$TE.direct[i] <- x$TE.direct.random[treat1[i], treat2[i]]
@@ -494,7 +495,7 @@ funnel.netmeta <- function(x,
          pch = res$pch,
          col = res$col,
          level = level,
-         fixed = FALSE, random = FALSE,
+         common = FALSE, random = FALSE,
          xlab = xlab,
          backtransf = backtransf,
          ref.triangle = TRUE,
@@ -508,11 +509,11 @@ funnel.netmeta <- function(x,
   }
   ##
   if (linreg)
-    mb.linreg <- metabias(m.adj, method = "Egger")
+    mb.linreg <- suppressWarnings(metabias(m.adj, method = "Egger"))
   if (rank)
-    mb.rank <- metabias(m.adj, method = "Begg")
+    mb.rank <- suppressWarnings(metabias(m.adj, method = "Begg"))
   if (mm)
-    mb.mm <- metabias(m.adj, method = "Thompson")
+    mb.mm <- suppressWarnings(metabias(m.adj, method = "Thompson"))
   ##
   if (linreg | rank | mm)
     legend(pos.tests,
