@@ -14,8 +14,8 @@
 #' @param sep.comps A single character to define separator between
 #'   treatment components.
 #' @param C.matrix C matrix (see Details).
-#' @param fixed A logical indicating whether a fixed effects / common
-#'   effects network meta-analysis should be conducted.
+#' @param common A logical indicating whether a common effects network
+#'   meta-analysis should be conducted.
 #' @param random A logical indicating whether a random effects network
 #'   meta-analysis should be conducted.
 #' @param tau.preset An optional value for the square-root of the
@@ -108,7 +108,7 @@
 #' \item{TE}{Estimate of treatment effect, i.e. difference between
 #'   first and second treatment.}
 #' \item{seTE}{Standard error of treatment estimate.}
-#' \item{seTE.adj.fixed, seTE.adj.random}{Standard error of treatment
+#' \item{seTE.adj.common, seTE.adj.random}{Standard error of treatment
 #'   estimate, adjusted for multi-arm studies.}
 #' \item{design}{Design of study providing pairwise comparison.}
 #' \item{event1}{Number of events in first treatment group.}
@@ -134,91 +134,91 @@
 #'   design corresponds to the set of treatments compared within a
 #'   study.}
 #' \item{comps}{Unique list of components present in the network.}
-#' \item{TE.nma.fixed, TE.nma.random}{A vector of length \emph{m} of
+#' \item{TE.nma.common, TE.nma.random}{A vector of length \emph{m} of
 #'   consistent treatment effects estimated by network meta-analysis
-#'   (nma) (fixed and random effects model).}
-#' \item{seTE.nma.fixed, seTE.nma.random}{A vector of length \emph{m}
+#'   (nma) (common and random effects model).}
+#' \item{seTE.nma.common, seTE.nma.random}{A vector of length \emph{m}
 #'   of effective standard errors estimated by network meta-analysis
-#'   (fixed and random effects model).}
-#' \item{lower.nma.fixed, lower.nma.random}{A vector of length
+#'   (common and random effects model).}
+#' \item{lower.nma.common, lower.nma.random}{A vector of length
 #'   \emph{m} of lower confidence interval limits for consistent
-#'   treatment effects estimated by network meta-analysis (fixed
+#'   treatment effects estimated by network meta-analysis (common
 #'   and random effects model).}
-#' \item{upper.nma.fixed, upper.nma.random}{A vector of length
+#' \item{upper.nma.common, upper.nma.random}{A vector of length
 #'   \emph{m} of upper confidence interval limits for the consistent
-#'   treatment effects estimated by network meta-analysis (fixed
+#'   treatment effects estimated by network meta-analysis (common
 #'   and random effects model).}
-#' \item{statistic.nma.fixed, statistic.nma.random}{A vector of length \emph{m}
+#' \item{statistic.nma.common, statistic.nma.random}{A vector of length \emph{m}
 #'   of z-values for test of treatment effect for individual
-#'   comparisons (fixed and random effects model).}
-#' \item{pval.nma.fixed, pval.nma.random}{A vector of length \emph{m}
+#'   comparisons (common and random effects model).}
+#' \item{pval.nma.common, pval.nma.random}{A vector of length \emph{m}
 #'   of p-values for test of treatment effect for individual
-#'   comparisons (fixed and random effects model).}
-#' \item{TE.cnma.fixed, TE.cnma.random}{A vector of length \emph{m} of
-#'   consistent treatment effects estimated by the additive (fixed and
+#'   comparisons (common and random effects model).}
+#' \item{TE.cnma.common, TE.cnma.random}{A vector of length \emph{m} of
+#'   consistent treatment effects estimated by the additive (common and
 #'   random effects) model.}
-#' \item{seTE.cnma.fixed, seTE.cnma.random}{A vector of length
-#'   \emph{m} with standard errors estimated by the additive (fixed
+#' \item{seTE.cnma.common, seTE.cnma.random}{A vector of length
+#'   \emph{m} with standard errors estimated by the additive (common
 #'   and random effects) model.}
-#' \item{lower.cnma.fixed, lower.cnma.random}{A vector of length
+#' \item{lower.cnma.common, lower.cnma.random}{A vector of length
 #'   \emph{m} of lower confidence interval limits for consistent
-#'   treatment effects estimated by the additive (fixed and random
+#'   treatment effects estimated by the additive (common and random
 #'   effects) model.}
-#' \item{upper.cnma.fixed, upper.cnma.random}{A vector of length
+#' \item{upper.cnma.common, upper.cnma.random}{A vector of length
 #'   \emph{m} of upper confidence interval limits for consistent
-#'   treatment effects estimated by the additive (fixed and random
+#'   treatment effects estimated by the additive (common and random
 #'   effects) model.}
-#' \item{statistic.cnma.fixed, statistic.cnma.random}{A vector of length
+#' \item{statistic.cnma.common, statistic.cnma.random}{A vector of length
 #'   \emph{m} of z-values for the test of an overall effect estimated
-#'   by the additive (fixed and random effects) model.}
-#' \item{pval.cnma.fixed, pval.cnma.random}{A vector of length
+#'   by the additive (common and random effects) model.}
+#' \item{pval.cnma.common, pval.cnma.random}{A vector of length
 #'   \emph{m} of p-values for the test of an overall effect estimated
-#'   by the additive (fixed and random effects) model.}
-#' \item{TE.fixed, TE.random}{\emph{n}x\emph{n} matrix with overall
-#'   treatment effects estimated by the additive (fixed and random
+#'   by the additive (common and random effects) model.}
+#' \item{TE.common, TE.random}{\emph{n}x\emph{n} matrix with overall
+#'   treatment effects estimated by the additive (common and random
 #'   effects) model.}
-#' \item{seTE.fixed, seTE.random}{\emph{n}x\emph{n} matrix with
-#'   standard errors estimated by the additive (fixed and random
+#' \item{seTE.common, seTE.random}{\emph{n}x\emph{n} matrix with
+#'   standard errors estimated by the additive (common and random
 #'   effects) model.}
-#' \item{lower.fixed, upper.fixed, lower.random,
+#' \item{lower.common, upper.common, lower.random,
 #'   upper.random}{\emph{n}x\emph{n} matrices with lower and upper
-#'   confidence interval limits estimated by the additive (fixed and
+#'   confidence interval limits estimated by the additive (common and
 #'   random effects) model.}
-#' \item{statistic.fixed, pval.fixed, statistic.random,
+#' \item{statistic.common, pval.common, statistic.random,
 #'   pval.random}{\emph{n}x\emph{n} matrices with z-values and
 #'   p-values for test of overall effect estimated by the additive
-#'   (fixed and random effects) model.}
-#' \item{Comp.fixed, Comp.random}{A vector of component effects (fixed
+#'   (common and random effects) model.}
+#' \item{Comp.common, Comp.random}{A vector of component effects (common
 #'   and random effects model).}
-#' \item{seComp.fixed, seComp.random}{A vector with corresponding
-#'   standard errors (fixed and random effects model).}
-#' \item{lower.Comp.fixed, lower.Comp.random}{A vector with lower
-#'   confidence limits for components (fixed and random effects
+#' \item{seComp.common, seComp.random}{A vector with corresponding
+#'   standard errors (common and random effects model).}
+#' \item{lower.Comp.common, lower.Comp.random}{A vector with lower
+#'   confidence limits for components (common and random effects
 #'   model).}
-#' \item{upper.Comp.fixed, upper.Comp.random}{A vector with upper
-#'   confidence limits for components (fixed and random effects
+#' \item{upper.Comp.common, upper.Comp.random}{A vector with upper
+#'   confidence limits for components (common and random effects
 #'   model).}
-#' \item{statistic.Comp.fixed, statistic.Comp.random}{A vector with z-values for
-#'   the overall effect of components (fixed and random effects
+#' \item{statistic.Comp.common, statistic.Comp.random}{A vector with z-values for
+#'   the overall effect of components (common and random effects
 #'   model).}
-#' \item{pval.Comp.fixed, pval.Comp.random}{A vector with p-values for
-#'   the overall effect of components (fixed and random effects
+#' \item{pval.Comp.common, pval.Comp.random}{A vector with p-values for
+#'   the overall effect of components (common and random effects
 #'   model).}
-#' \item{Comb.fixed, Comb.random}{A vector of combination effects
-#'   (fixed and random effects model).}
-#' \item{seComb.fixed, seComb.random}{A vector with corresponding
-#'   standard errors (fixed and random effects model).}
-#' \item{lower.Comb.fixed, lower.Comb.random}{A vector with lower
-#'   confidence limits for combinations (fixed and random effects
+#' \item{Comb.common, Comb.random}{A vector of combination effects
+#'   (common and random effects model).}
+#' \item{seComb.common, seComb.random}{A vector with corresponding
+#'   standard errors (common and random effects model).}
+#' \item{lower.Comb.common, lower.Comb.random}{A vector with lower
+#'   confidence limits for combinations (common and random effects
 #'   model).}
-#' \item{upper.Comb.fixed, upper.Comb.random}{A vector with upper
-#'   confidence limits for combinations (fixed and random effects
+#' \item{upper.Comb.common, upper.Comb.random}{A vector with upper
+#'   confidence limits for combinations (common and random effects
 #'   model).}
-#' \item{statistic.Comb.fixed, statistic.Comb.random}{A vector with
-#'   z-values for the overall effect of combinations (fixed and random
+#' \item{statistic.Comb.common, statistic.Comb.random}{A vector with
+#'   z-values for the overall effect of combinations (common and random
 #'   effects model).}
-#' \item{pval.Comb.fixed, pval.Comb.random}{A vector with p-values for
-#'   the overall effect of combinations (fixed and random effects
+#' \item{pval.Comb.common, pval.Comb.random}{A vector with p-values for
+#'   the overall effect of combinations (common and random effects
 #'   model).}
 #' \item{Q.additive}{Overall heterogeneity / inconsistency statistic
 #'   (additive model).}
@@ -246,7 +246,7 @@
 #' \item{C.matrix}{As defined above.}
 #' \item{sm}{Summary measure.}
 #' \item{level.ma}{Level for confidence intervals.}
-#' \item{fixed, random, tau.preset}{As defined above.}
+#' \item{common, random, tau.preset}{As defined above.}
 #' \item{sep.trts}{A character used in comparison names as separator
 #'   between treatment labels.}
 #' \item{nchar.comps}{A numeric defining the minimum number of
@@ -302,8 +302,7 @@
 #' # Conduct random effects network meta-analysis
 #' #
 #' net1 <- netmeta(lnOR, selnOR, treat1, treat2, id,
-#'                 data = face, ref = "placebo",
-#'                 sm = "OR", fixed = FALSE)
+#'   data = face, ref = "placebo", sm = "OR", common = FALSE)
 #' net1
 #' forest(net1, xlim = c(0.2, 50))
 #' 
@@ -318,11 +317,11 @@
 #' # Specify, order of treatments
 #' #
 #' trts <- c("TCA", "SSRI", "SNRI", "NRI", "Low-dose SARI", "NaSSa",
-#'           "rMAO-A", "Ind drug", "Hypericum", "Face-to-face CBT",
-#'           "Face-to-face PST", "Face-to-face interpsy", "Face-to-face psychodyn",
-#'           "Other face-to-face", "Remote CBT", "Self-help CBT", "No contact CBT",
-#'           "Face-to-face CBT + SSRI", "Face-to-face interpsy + SSRI",
-#'           "Face-to-face PST + SSRI", "UC", "Placebo")
+#'   "rMAO-A", "Ind drug", "Hypericum", "Face-to-face CBT",
+#'   "Face-to-face PST", "Face-to-face interpsy", "Face-to-face psychodyn",
+#'   "Other face-to-face", "Remote CBT", "Self-help CBT", "No contact CBT",
+#'   "Face-to-face CBT + SSRI", "Face-to-face interpsy + SSRI",
+#'   "Face-to-face PST + SSRI", "UC", "Placebo")
 #' #
 #' # Note, three treatments are actually combinations of 'SSRI' with
 #' # other components:
@@ -333,9 +332,8 @@
 #' # Conduct random effects network meta-analysis
 #' #
 #' net1 <- netmeta(lnOR, selnOR, treat1, treat2, id,
-#'                 data = Linde2016, ref = "placebo",
-#'                 seq = trts,
-#'                 sm = "OR", fixed = FALSE)
+#'   data = Linde2016, ref = "placebo",
+#'   seq = trts, sm = "OR", common = FALSE)
 #' net1
 #' forest(net1, xlim = c(0.2, 50))
 #' 
@@ -354,7 +352,7 @@ netcomb <- function(x,
                     inactive = NULL,
                     sep.comps = "+",
                     C.matrix,
-                    fixed = x$fixed,
+                    common = x$common,
                     random = x$random | !is.null(tau.preset),
                     tau.preset = NULL,
                     details.chkident = FALSE,
@@ -389,10 +387,12 @@ netcomb <- function(x,
   args  <- list(...)
   chklogical(warn.deprecated)
   ##
-  missing.fixed <- missing(fixed)
-  fixed <- deprecated(fixed, missing.fixed, args, "comb.fixed",
-                      warn.deprecated)
-  chklogical(fixed)
+  missing.common <- missing(common)
+  common <- deprecated(common, missing.common, args, "comb.fixed",
+                       warn.deprecated)
+  common <- deprecated(common, missing.common, args, "fixed",
+                       warn.deprecated)
+  chklogical(common)
   ##
   random <-
     deprecated(random, missing(random), args, "comb.random", warn.deprecated)
@@ -401,26 +401,7 @@ netcomb <- function(x,
   
   ##
   ##
-  ## (2) Get data
-  ##
-  ##
-  n <- x$n # number of treatments / combinations
-  m <- x$m # number of comparisons
-  ##
-  trts <- x$trts
-  ##
-  TE <- x$TE
-  seTE <- x$seTE
-  treat1 <- x$treat1
-  treat2 <- x$treat2
-  studlab <- x$studlab
-  ##
-  B.matrix <- x$B.matrix
-  
-  
-  ##
-  ##
-  ## (3) Create C.matrix
+  ## (2) Create C.matrix
   ##
   ##
   if (missing(C.matrix)) {
@@ -433,7 +414,7 @@ netcomb <- function(x,
       C.matrix <- createC(x, sep.comps, inactive)
     ##
     inactive <- attr(C.matrix, "inactive")
-    C.matrix <- as.matrix(C.matrix)[trts, , drop = FALSE]
+    C.matrix <- as.matrix(C.matrix)[x$trts, , drop = FALSE]
   }
   else {
     ##
@@ -443,7 +424,7 @@ netcomb <- function(x,
       stop("Argument 'C.matrix' must be a matrix or data frame.",
            call. = FALSE)
     ##
-    if (nrow(C.matrix) != n)
+    if (nrow(C.matrix) != x$n)
       stop("Argument 'C.matrix' has wrong number of rows",
            " (must be equal to number of treatments).",
            call. = FALSE)
@@ -455,15 +436,15 @@ netcomb <- function(x,
     if (is.null(rownames(C.matrix)))
       wrong.labels <- TRUE
     else {
-      if (length(unique(trts)) ==
-          length(unique(tolower(trts))) &&
+      if (length(unique(x$trts)) ==
+          length(unique(tolower(x$trts))) &&
           length(unique(rownames(C.matrix))) ==
           length(unique(tolower(rownames(C.matrix))))
           )
         idx <- charmatch(tolower(rownames(C.matrix)),
-                         tolower(trts), nomatch = NA)
+                         tolower(x$trts), nomatch = NA)
       else
-        idx <- charmatch(rownames(C.matrix), trts, nomatch = NA)
+        idx <- charmatch(rownames(C.matrix), x$trts, nomatch = NA)
       ##
       if (any(is.na(idx)) || any(idx == 0))
         wrong.labels <- TRUE
@@ -472,11 +453,11 @@ netcomb <- function(x,
     if (wrong.labels)
       stop(paste("Row names of argument 'C.matrix' must be a ",
                  "permutation of treatment names:\n  ",
-                 paste(paste("'", trts, "'", sep = ""),
+                 paste(paste("'", x$trts, "'", sep = ""),
                        collapse = " - "), sep = ""),
            call. = FALSE)
     ##
-    C.matrix <- C.matrix[trts, , drop = FALSE]
+    C.matrix <- C.matrix[x$trts, , drop = FALSE]
     ##
     if (is.data.frame(C.matrix))
       C.matrix <- as.matrix(C.matrix)
@@ -485,24 +466,16 @@ netcomb <- function(x,
   c <- ncol(C.matrix) # number of components
   
   
-  p0 <- prepare(TE, seTE, treat1, treat2, studlab,
-                func.inverse = func.inverse)
   ##
-  o <- order(p0$order)
   ##
-  B.matrix <- createB(p0$treat1.pos[o], p0$treat2.pos[o])
+  ## (3) Create design matrix based on treatment components
   ##
-  colnames(B.matrix) <- trts
-  rownames(B.matrix) <- studlab
-  
-  
-  ##
-  ## Design matrix based on treatment components
-  ##
-  X.matrix <- B.matrix %*% C.matrix
   ##
+  X.matrix <- x$B.matrix %*% C.matrix
   colnames(X.matrix) <- colnames(C.matrix)
-  rownames(X.matrix) <- studlab
+  rownames(X.matrix) <- x$studlab
+  ##
+  ## Check for and warn about not uniquely identifiable components
   ##
   if (qr(X.matrix)$rank < c) {
     Xplus <- ginv(X.matrix)
@@ -515,8 +488,8 @@ netcomb <- function(x,
     ##
     if (dim(M)[2] > 0) {
       sel.ident <- character(0)
-      for (m in 1:dim(M)[2])
-        sel.ident <- c(sel.ident, names(M[, m])[!is.zero(M[, m], n = 100)])
+      for (i in 1:dim(M)[2])
+        sel.ident <- c(sel.ident, names(M[, i])[!is.zero(M[, i], n = 100)])
       ##
       sel.ident <- unique(sort(sel.ident))
       warning(paste0("The following component",
@@ -539,58 +512,56 @@ netcomb <- function(x,
   
   
   ##
-  ## Fixed effects models
+  ##
+  ## (4) Conduct CNMA
+  ##
   ##
   df.Q.additive <- x$df.Q + x$n - 1 - qr(X.matrix)$rank
-  ##
-  net <- netmeta(TE, seTE, treat1, treat2, studlab,
-                 tol.multiarm = x$tol.multiarm,
-                 tol.multiarm.se = x$tol.multiarm.se,
-                 details.chkmultiarm = x$details.chkmultiarm)
-  ##
-  Q <- net$Q
-  df.Q <- net$df.Q
-  pval.Q <- net$pval.Q
-  ##
   df.Q.diff <- x$n - 1 - qr(X.matrix)$rank
-  
-  
-  res.f <- nma.additive(p0$TE[o], p0$weights[o], p0$studlab[o],
+  ##
+  p0 <- prepare(x$TE, x$seTE, x$treat1, x$treat2, x$studlab,
+                func.inverse = func.inverse)
+  ##
+  o <- order(p0$order)
+  ##
+  ## Common effects models
+  ##
+  res.c <- nma.additive(p0$TE[o], p0$weights[o], p0$studlab[o],
                         p0$treat1[o], p0$treat2[o], x$level.ma,
-                        X.matrix, C.matrix, B.matrix,
-                        Q, df.Q.additive, df.Q.diff,
+                        X.matrix, C.matrix, x$B.matrix,
+                        x$Q, df.Q.additive, df.Q.diff,
                         x$n, x$sep.trts)
-  
-  
   ##
   ## Calculate heterogeneity statistics (additive model)
   ##
-  Q.additive <- res.f$Q.additive
+  Q.additive <- res.c$Q.additive
   ##
   if (!is.null(tau.preset))
     tau <- tau.preset
   else
-    tau <- res.f$tau
+    tau <- res.c$tau
   ##
-  I2 <- res.f$I2
-  lower.I2 <- res.f$lower.I2
-  upper.I2 <- res.f$upper.I2
-  ##
-  tau2.calc <- if (is.na(tau)) 0 else tau^2
-  
-  
+  I2 <- res.c$I2
+  lower.I2 <- res.c$lower.I2
+  upper.I2 <- res.c$upper.I2
   ##
   ## Random effects models
   ##
-  p1 <- prepare(TE, seTE, treat1, treat2, studlab, tau, invmat)
+  p1 <- prepare(x$TE, x$seTE, x$treat1, x$treat2, x$studlab,
+                if (is.na(tau)) 0 else tau, invmat)
   ##
   res.r <- nma.additive(p1$TE[o], p1$weights[o], p1$studlab[o],
                         p1$treat1[o], p1$treat2[o], x$level.ma,
-                        X.matrix, C.matrix, B.matrix,
-                        Q, df.Q.additive, df.Q.diff,
+                        X.matrix, C.matrix, x$B.matrix,
+                        x$Q, df.Q.additive, df.Q.diff,
                         x$n, x$sep.trts)
   
   
+  ##
+  ##
+  ## (5) Generate CNMA object
+  ##
+  ##
   res <- list(studlab = x$studlab,
               treat1 = x$treat1,
               treat2 = x$treat2,
@@ -598,7 +569,7 @@ netcomb <- function(x,
               TE = x$TE,
               seTE = x$seTE,
               seTE.adj = x$seTE.adj,
-              seTE.adj.fixed = x$seTE.adj.fixed,
+              seTE.adj.common = x$seTE.adj.common,
               seTE.adj.random = x$seTE.adj.random,
               ##
               design = x$design,
@@ -609,12 +580,12 @@ netcomb <- function(x,
               n2 = x$n2,
               ##
               k = x$k,
-              m = m,
-              n = n,
+              m = x$m,
+              n = x$n,
               d = x$d,
               c = c,
               ##
-              trts = trts,
+              trts = x$trts,
               k.trts = x$k.trts,
               n.trts = x$n.trts,
               events.trts = x$events.trts,
@@ -627,31 +598,31 @@ netcomb <- function(x,
               ##
               designs = x$designs,
               ##
-              comps = names(res.f$components$TE),
+              comps = names(res.c$components$TE),
               k.comps = NA,
               n.comps = NA,
               events.comps = NA,
               ##
-              TE.nma.fixed = x$TE.nma.fixed,
-              seTE.nma.fixed = x$seTE.nma.fixed,
-              lower.nma.fixed = x$lower.nma.fixed,
-              upper.nma.fixed = x$upper.nma.fixed,
-              statistic.nma.fixed = x$statistic.nma.fixed,
-              pval.nma.fixed = x$pval.nma.fixed,
+              TE.nma.common = x$TE.nma.common,
+              seTE.nma.common = x$seTE.nma.common,
+              lower.nma.common = x$lower.nma.common,
+              upper.nma.common = x$upper.nma.common,
+              statistic.nma.common = x$statistic.nma.common,
+              pval.nma.common = x$pval.nma.common,
               ##
-              TE.cnma.fixed = res.f$comparisons$TE,
-              seTE.cnma.fixed = res.f$comparisons$seTE,
-              lower.cnma.fixed = res.f$comparisons$lower,
-              upper.cnma.fixed = res.f$comparisons$upper,
-              statistic.cnma.fixed = res.f$comparisons$statistic,
-              pval.cnma.fixed = res.f$comparisons$p,
+              TE.cnma.common = res.c$comparisons$TE,
+              seTE.cnma.common = res.c$comparisons$seTE,
+              lower.cnma.common = res.c$comparisons$lower,
+              upper.cnma.common = res.c$comparisons$upper,
+              statistic.cnma.common = res.c$comparisons$statistic,
+              pval.cnma.common = res.c$comparisons$p,
               ##
-              TE.fixed = res.f$all.comparisons$TE,
-              seTE.fixed = res.f$all.comparisons$seTE,
-              lower.fixed = res.f$all.comparisons$lower,
-              upper.fixed = res.f$all.comparisons$upper,
-              statistic.fixed = res.f$all.comparisons$statistic,
-              pval.fixed = res.f$all.comparisons$p,
+              TE.common = res.c$all.comparisons$TE,
+              seTE.common = res.c$all.comparisons$seTE,
+              lower.common = res.c$all.comparisons$lower,
+              upper.common = res.c$all.comparisons$upper,
+              statistic.common = res.c$all.comparisons$statistic,
+              pval.common = res.c$all.comparisons$p,
               ##
               TE.nma.random = x$TE.nma.random,
               seTE.nma.random = x$seTE.nma.random,
@@ -674,12 +645,12 @@ netcomb <- function(x,
               statistic.random = res.r$all.comparisons$statistic,
               pval.random = res.r$all.comparisons$p,
               ##
-              Comp.fixed = unname(res.f$components$TE),
-              seComp.fixed = unname(res.f$components$seTE),
-              lower.Comp.fixed = unname(res.f$components$lower),
-              upper.Comp.fixed = unname(res.f$components$upper),
-              statistic.Comp.fixed = unname(res.f$components$statistic),
-              pval.Comp.fixed = unname(res.f$components$p),
+              Comp.common = unname(res.c$components$TE),
+              seComp.common = unname(res.c$components$seTE),
+              lower.Comp.common = unname(res.c$components$lower),
+              upper.Comp.common = unname(res.c$components$upper),
+              statistic.Comp.common = unname(res.c$components$statistic),
+              pval.Comp.common = unname(res.c$components$p),
               ##
               Comp.random = unname(res.r$components$TE),
               seComp.random = unname(res.r$components$seTE),
@@ -688,12 +659,12 @@ netcomb <- function(x,
               statistic.Comp.random = unname(res.r$components$statistic),
               pval.Comp.random = unname(res.r$components$p),
               ##
-              Comb.fixed = unname(res.f$combinations$TE),
-              seComb.fixed = unname(res.f$combinations$seTE),
-              lower.Comb.fixed = unname(res.f$combinations$lower),
-              upper.Comb.fixed = unname(res.f$combinations$upper),
-              statistic.Comb.fixed = unname(res.f$combinations$statistic),
-              pval.Comb.fixed = unname(res.f$combinations$p),
+              Comb.common = unname(res.c$combinations$TE),
+              seComb.common = unname(res.c$combinations$seTE),
+              lower.Comb.common = unname(res.c$combinations$lower),
+              upper.Comb.common = unname(res.c$combinations$upper),
+              statistic.Comb.common = unname(res.c$combinations$statistic),
+              pval.Comb.common = unname(res.c$combinations$p),
               ##
               Comb.random = unname(res.r$combinations$TE),
               seComb.random = unname(res.r$combinations$seTE),
@@ -704,7 +675,7 @@ netcomb <- function(x,
               ##
               Q.additive = Q.additive,
               df.Q.additive = df.Q.additive,
-              pval.Q.additive = res.f$pval.Q.additive,
+              pval.Q.additive = res.c$pval.Q.additive,
               tau = tau,
               I2 = I2, lower.I2 = lower.I2, upper.I2 = upper.I2,
               ##
@@ -712,34 +683,34 @@ netcomb <- function(x,
               df.Q.standard = x$df.Q,
               pval.Q.standard = x$pval.Q,
               ##
-              Q.diff = res.f$Q.diff,
+              Q.diff = res.c$Q.diff,
               df.Q.diff = df.Q.diff,
-              pval.Q.diff = res.f$pval.Q.diff, 
+              pval.Q.diff = res.c$pval.Q.diff, 
               ##
               A.matrix = x$A.matrix,
               X.matrix = X.matrix,
-              B.matrix = B.matrix,
+              B.matrix = x$B.matrix,
               C.matrix = C.matrix,
               ##
-              L.matrix.fixed = res.f$L.matrix,
-              Lplus.matrix.fixed = res.f$Lplus.matrix,
+              L.matrix.common = res.c$L.matrix,
+              Lplus.matrix.common = res.c$Lplus.matrix,
               L.matrix.random = res.r$L.matrix,
               Lplus.matrix.random = res.r$Lplus.matrix,
               ##
-              H.matrix.fixed = res.f$H.matrix[o, o],
+              H.matrix.common = res.c$H.matrix[o, o],
               H.matrix.random = res.r$H.matrix[o, o],
               ##
               n.matrix = x$n.matrix,
               events.matrix = x$events.matrix,
               ##
-              Cov.fixed = x$Cov.fixed,
+              Cov.common = x$Cov.common,
               Cov.random = x$Cov.random,
               ##
               sm = x$sm,
               method = "Inverse",
               level = x$level,
               level.ma = x$level.ma,
-              fixed = x$fixed,
+              common = x$common,
               random = x$random,
               ##
               reference.group = x$reference.group,
@@ -769,6 +740,51 @@ netcomb <- function(x,
               version = packageDescription("netmeta")$Version
               )
   ##
+  ## Backward compatibility
+  ##
+  res$fixed <- res$common
+  res$comb.fixed <- res$common
+  res$comb.random <- res$random
+  ##
+  res$seTE.adj.fixed <- res$seTE.adj.common
+  res$TE.nma.fixed <- res$TE.nma.common
+  res$seTE.nma.fixed <- res$seTE.nma.common
+  res$lower.nma.fixed <- res$lower.nma.common
+  res$upper.nma.fixed <- res$upper.nma.common
+  res$statistic.nma.fixed <- res$statistic.nma.common
+  res$pval.nma.fixed <- res$pval.nma.common
+  res$TE.cnma.fixed <- res$TE.cnma.common
+  res$seTE.cnma.fixed <- res$seTE.cnma.common
+  res$lower.cnma.fixed <- res$lower.cnma.common
+  res$upper.cnma.fixed <- res$upper.cnma.common
+  res$statistic.cnma.fixed <- res$statistic.cnma.common
+  res$pval.cnma.fixed <- res$pval.cnma.common
+  ##
+  res$TE.fixed <- res$TE.common
+  res$seTE.fixed <- res$seTE.common
+  res$lower.fixed <- res$lower.common
+  res$upper.fixed <- res$upper.common
+  res$statistic.fixed <- res$statistic.common
+  res$pval.fixed <- res$pval.common
+  ##
+  res$Comp.fixed <- res$Comp.common
+  res$seComp.fixed <- res$seComp.common
+  res$lower.Comp.fixed <- res$lower.Comp.common
+  res$upper.Comp.fixed <- res$upper.Comp.common
+  res$statistic.Comp.fixed <- res$statistic.Comp.common
+  res$pval.Comp.fixed <- res$pval.Comp.common
+  ##
+  res$Comb.fixed <- res$Comb.common
+  res$seComb.fixed <- res$seComb.common
+  res$lower.Comb.fixed <- res$lower.Comb.common
+  res$upper.Comb.fixed <- res$upper.Comb.common
+  res$statistic.Comb.fixed <- res$statistic.Comb.common
+  res$pval.Comb.fixed <- res$pval.Comb.common
+  ##
+  res$L.matrix.fixed <- res$L.matrix.common
+  res$Lplus.matrix.fixed <- res$Lplus.matrix.common
+  res$H.matrix.fixed <- res$H.matrix.common        
+  ##
   class(res) <- "netcomb"
   
   
