@@ -44,11 +44,10 @@
 #' #
 #' studies <- unique(Franchini2012$Study)
 #' p1 <- pairwise(list(Treatment1, Treatment2, Treatment3),
-#'                n = list(n1, n2, n3),
-#'                mean = list(y1, y2, y3),
-#'                sd = list(sd1, sd2, sd3),
-#'                data = subset(Franchini2012, Study %in% studies[1:2]),
-#'                studlab = Study)
+#'   n = list(n1, n2, n3),
+#'   mean = list(y1, y2, y3), sd = list(sd1, sd2, sd3),
+#'   data = subset(Franchini2012, Study %in% studies[1:2]),
+#'   studlab = Study)
 #' 
 #' net1 <- netmeta(p1)
 #' ni <- netimpact(net1, verbose = TRUE)
@@ -96,7 +95,7 @@ netgraph.netimpact <- function(x,
   comparison <- paste(treat1, sep = sep.trts, treat2)
   
   
-  comparisons <- names(x$x$prop.direct.fixed)
+  comparisons <- names(x$x$prop.direct.common)
   studies <- x$x$studies
   narms <- x$x$narms
   ##  
