@@ -9,7 +9,7 @@
 #'   plot or biplot should be produced, either \code{"scatter"} or
 #'   \code{"biplot"}. Can be abbreviated.
 #' @param pooled A character string indicating whether scatter plot
-#'   should be drawn for fixed (\code{"fixed"}) or random effects
+#'   should be drawn for common (\code{"common"}) or random effects
 #'   model (\code{"random"}). Can be abbreviated.
 #' @param dim A character string indicating whether a 2- or
 #'   3-dimensional plot should be produced, either \code{"2d"} or
@@ -113,8 +113,7 @@
 #' # Define order of treatments
 #' #
 #' trts <- c("TCA", "SSRI", "SNRI", "NRI",
-#'           "Low-dose SARI", "NaSSa", "rMAO-A", "Hypericum",
-#'           "Placebo")
+#'   "Low-dose SARI", "NaSSa", "rMAO-A", "Hypericum", "Placebo")
 #' #
 #' # Outcome labels
 #' #
@@ -123,22 +122,20 @@
 #' # (1) Early response
 #' #
 #' p1 <- pairwise(treat = list(treatment1, treatment2, treatment3),
-#'                event = list(resp1, resp2, resp3),
-#'                n = list(n1, n2, n3),
-#'                studlab = id, data = Linde2015, sm = "OR")
+#'   event = list(resp1, resp2, resp3), n = list(n1, n2, n3),
+#'   studlab = id, data = Linde2015, sm = "OR")
 #' #
-#' net1 <- netmeta(p1, fixed = FALSE,
-#'                 seq = trts, ref = "Placebo", small.values = "bad")
+#' net1 <- netmeta(p1, common = FALSE,
+#'   seq = trts, ref = "Placebo", small.values = "bad")
 #' 
 #' # (2) Early remission
 #' #
 #' p2 <- pairwise(treat = list(treatment1, treatment2, treatment3),
-#'                event = list(remi1, remi2, remi3),
-#'                n = list(n1, n2, n3),
-#'                studlab = id, data = Linde2015, sm = "OR")
+#'   event = list(remi1, remi2, remi3), n = list(n1, n2, n3),
+#'   studlab = id, data = Linde2015, sm = "OR")
 #' #
-#' net2 <- netmeta(p2, fixed = FALSE,
-#'                 seq = trts, ref = "Placebo", small.values = "bad")
+#' net2 <- netmeta(p2, common = FALSE,
+#'   seq = trts, ref = "Placebo", small.values = "bad")
 #' 
 #' # Partial order of treatment rankings
 #' #
@@ -162,17 +159,16 @@
 #' # (3) Loss to follow-up
 #' #
 #' p3 <- pairwise(treat = list(treatment1, treatment2, treatment3),
-#'                event = list(loss1, loss2, loss3),
-#'                n = list(n1, n2, n3),
-#'                studlab = id, data = Linde2015, sm = "OR")
+#'   event = list(loss1, loss2, loss3), n = list(n1, n2, n3),
+#'   studlab = id, data = Linde2015, sm = "OR")
 #' #
-#' net3 <- netmeta(p3, fixed = FALSE,
-#'                 seq = trts, ref = "Placebo", small.values = "good")
+#' net3 <- netmeta(p3, common = FALSE,
+#'   seq = trts, ref = "Placebo", small.values = "good")
 #' 
 #' # Partial order of treatment rankings (with three outcomes) 
 #' #
 #' po3 <- netposet(netrank(net1), netrank(net2), netrank(net3),
-#'                 outcomes = outcomes)
+#'   outcomes = outcomes)
 #' 
 #' # Hasse diagram
 #' #
@@ -193,7 +189,7 @@
 
 plot.netposet <- function(x,
                           plottype = "scatter",
-                          pooled = ifelse(x$random, "random", "fixed"),
+                          pooled = ifelse(x$random, "random", "common"),
                           dim = "2d",
                           sel.x = 1, sel.y = 2, sel.z = 3,
                           cex = 1, col = "black",
@@ -212,12 +208,13 @@ plot.netposet <- function(x,
   chkclass(x, "netposet")
   x <- updateversion(x)
   ##
-  pooled <- setchar(pooled, c("fixed", "random"))
+  pooled <- setchar(pooled, c("common", "random", "fixed"))
+  pooled[pooled == "fixed"] <- "common"
   
   
-  if (pooled == "fixed") {
-    p.matrix <- x$P.fixed
-    M0 <- x$M0.fixed
+  if (pooled == "common") {
+    p.matrix <- x$P.common
+    M0 <- x$M0.common
   }
   else {
     p.matrix <- x$P.random
